@@ -2,7 +2,7 @@ WFO.url <- function(
     WFO.result=NULL, browse=FALSE, browse.rows=c(1:1), ...
 )
 {
-    if (class(WFO.result) == "character") {WFO.result <- data.frame(taxonID = WFO.result)}
+    if (class(WFO.result) %in% c("data.frame") == FALSE) {WFO.result <- data.frame(taxonID = WFO.result)}
     if (is.factor(WFO.result) == TRUE) {WFO.result <- data.frame(taxonID = WFO.result)}
 
     result <- as.character(NA, length=nrow(WFO.result))
